@@ -24,11 +24,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "kcalc.h"
 
-#include <cctype>
 #include <clocale>
-#include <cstdio>
-#include <cstdlib>
-#include <unistd.h>
 
 #include <QApplication>
 #include <QCursor>
@@ -60,13 +56,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <ktoolbar.h>
 #include <kxmlguifactory.h>
 
-#include "kcalcdisplay.h"
-#include "kcalc_const_menu.h"
-#include "version.h"
-#include "kcalc_settings.h"
 #include "kcalc_bitset.h"
-
-class QActionGroup;
+#include "kcalc_const_menu.h"
+#include "kcalc_settings.h"
+#include "kcalcdisplay.h"
+#include "version.h"
 
 namespace {
 const char description[] = I18N_NOOP("KDE Calculator");
@@ -2288,7 +2282,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[]) {
 		ki18n(description),
 		KAboutData::License_GPL,
 		ki18n(
-			"&copy; 2008-2012, Evan Teran\n"
+			"&copy; 2008-2013, Evan Teran\n"
 			"&copy; 2000-2008, The KDE Team\n"
 			"&copy; 2003-2005, Klaus Niederkr" "\xc3\xbc" "ger\n"
 			"&copy; 1996-2000, Bernd Johannes Wuebben"),
